import numpy as np
import matplotlib.pyplot as plt
import climt
from netCDF4 import Dataset
import seaborn as sns

sns.set_style('darkgrid')

ncdf = Dataset('radequil.nc')
lev  = ncdf.variables['lev'][:]
Trad = np.squeeze(ncdf.variables['T'][-5:,:]).mean(axis=0)
ncdf.close()

ncdf = Dataset('rce_dry.nc')
Tdry = np.squeeze(ncdf.variables['T'][-5:,:]).mean(axis=0)
ncdf.close()

ncdf = Dataset('rce.nc')
Trce = np.squeeze(ncdf.variables['T'][-5:,:]).mean(axis=0)
ncdf.close()

# calculate adiabats
thra = climt.thermodyn.theta(Tdry[0], lev[0])
thrd = climt.thermodyn.theta(Tdry[0], lev[0])
thrc = climt.thermodyn.theta(Tdry[0], lev[0])
drrd = np.empty(lev.shape)
for ii in range(len(lev)):
    drrd[ii] = climt.thermodyn.tdryadiab(thrd, lev[ii], 0)
msrc = climt.thermodyn.pseudoadiab(lev, lev[0], Trce[0])

# plot
fig = plt.figure()
axs = fig.add_subplot(111)
axs.plot(Trad, lev, color='#1b9e77', linewidth=3, label='Radiative equilibrium')
axs.plot(drrd, lev, color='#d95f02', linestyle='--', label='Dry adiabat')
axs.plot(Tdry, lev, color='#d95f02', linewidth=3, label='Dry RCE')
axs.plot(msrc, lev, color='#7570b3', linestyle=':', label='Moist adiabat')
axs.plot(Trce, lev, color='#7570b3', linewidth=3, label='Moist RCE')
axs.set_ylim(1000,20)
axs.set_ylabel('Pressure [hPa]')
axs.set_xlabel('Temperature [K]')
axs.legend(loc=3)
plt.savefig('../figs/rce.png', bbox_inches='tight')