import numpy as np
import climt

# Parameters
kwargs                   = {}
# constant relative humidity at 80%
rh                       = 0.8
# time step is one minute
kwargs['dt']             = 3600.
# plots to show daily
kwargs['MonitorFields']  = ['T','q','TdotRad','TdotTurb']
kwargs['MonitorFreq']    = 86400.
# output data every ten days
kwargs['OutputFile']     = 'radequil.nc'
kwargs['OutputFreq']     = 86400. * 10.
# suppress surface evaporative flux
kwargs['do_srf_lat_flx'] = 0

# reset specific humidity based on constant RH
def getRelHum():
    q = climt.thermodyn.qsflatau(fed.State['T'],
                                 fed.State['p'], 1) * rh
    q = np.maximum(q, q*0.+1.e-16)
    return np.reshape(q, np.shape(fed.State['p']))

# create component models (radiation time step is 4 minutes)
rad = climt.radiation(UpdateFreq=14400, scheme='chou')
dif = climt.turbulence()
oce = climt.ocean()
# initial conditions (temp profile is set to skin temp)
kwargs['q'] = np.zeros(rad.nlev) + 1.e-9
kwargs['T'] = np.zeros(rad.nlev) + \
              (rad['solin']/2./rad['stebol'])**0.25
# use federation class to couple components
fed = climt.federation(dif, rad, oce, **kwargs)

# main timestepping loop
RunLength = 1000.   # Total length of run (days)
NSteps    = int(RunLength*86400./fed['dt'])
for i in range(NSteps):
    fed.State['q'] = getRelHum() # impose constant relative humidity
    fed.step()
    time = fed.State.ElapsedTime
    if int(time/86400.) != int((time-fed['dt'])/86400.):
        print 'Surface temp: %10.5f' % (fed['Ts'])