import numpy as np
import climt

# Parameters
kwargs                   = {}
# time step is one minute
kwargs['dt']             = 360.
# stability parameter for leapfrog-type time steps
kwargs['afc'] = 0.2
# plots to show daily
kwargs['MonitorFields']  = ['T','q','TdotRad','TdotConv']
kwargs['MonitorFreq']    = 86400.
# output data every ten days
kwargs['OutputFile']     = 'rce.nc'
kwargs['OutputFreq']     = 86400. * 10.

# create component models (radiation time step is 4 minutes)
rad = climt.radiation(UpdateFreq=14400, scheme='chou')
dif = climt.turbulence()
con = climt.convection(scheme='emanuel')
oce = climt.ocean()
# initial conditions (temp profile is set to skin temp)
kwargs['T'] = np.zeros(rad.nlev) + \
              (rad['solin']/2./rad['stebol'])**0.25
kwargs['q'] = np.zeros(rad.nlev) + 1.e-6
# use federation class to couple components
fed = climt.federation(dif, rad, oce, con, **kwargs)

# main timestepping loop
RunLength = 1000.   # Total length of run (days)
NSteps    = int(RunLength*86400./fed['dt'])
for i in range(NSteps):
    fed.step()
    time = fed.State.ElapsedTime
    if int(time/86400.) != int((time-fed['dt'])/86400.):
        print 'Surface temp: %10.5f' % (fed['Ts'])