import numpy as np
import matplotlib.pyplot as plt
import climt
import csv

# read in measured profiles from Lhasa (26 May 2012)
infile = 'profile.csv'
Tmeas = []; pmeas = []; rmeas = []
with open(infile,'rb') as csvfile:
    reader = csv.reader(csvfile)
    # skip header lines
    for ii in range(2): reader.next()
    for row in reader:
        row = np.array(row).astype('float')
        pmeas.append(row[0])        # p [hPa]
        Tmeas.append(row[2]+273.16) # T [K]
        rmeas.append(row[7]*0.01)   # RH [fraction]
Tmeas = np.array(Tmeas)
pmeas = np.array(pmeas)
rmeas = np.array(rmeas)
# estimate specific humidity from RH and saturation SH
qmeas = rmeas*climt.thermodyn.qs(Tmeas, pmeas)
# calculate dewpoint temperature from T and q
Tdew  = climt.thermodyn.tdew(Tmeas, qmeas)

# plot skew-T diagram
climt.thermodyn.skewT(pmeas, Tmeas-273.16, Tdew-273.16)
plt.savefig('../figs/skewT.png', bbox_inches='tight')